Learn R Programming

parlitools (version 0.3.1)

bes_2017: 2017 General Election Results

Description

A tibble with the British Election Study 2017 Constituency Results Version 1.0.

Usage

bes_2017

Arguments

Format

A tibble, containing 632 rows and 123 columns. For full details on the included variables see the vignette: <http://docs.evanodell.com/parlitools/articles/bes-2017.html>

Details

A tibble with Great Britain constituencies results from the 2017 General Election. This data can be linked to 2011 census information in census_11 with the pano, ons_const_id and constituency_name variables.

Variable names have been converted to snake_case and variables have been converted to appropriate R classes.

References

Fieldhouse, E., J. Green., G. Evans., H. Schmitt, C. van der Eijk, J. Mellon & C. Prosser (2017) British Election Study 2017 Constituency Results file, version 1.0.

See Also

bes_2015

census_2011